@@ -9,7 +9,7 @@ function(x, sigma=1, lambda=0, eta=0, log=FALSE)
         stop("lambda must be specified")
     if (is.null(eta)) 
         stop("eta must be specified")
-    if (sigma <= 0) 
+    if (any(sigma <= 0)) 
         stop("sigma must be positive")
 lf=-log(2)-log(sigma)-pnorm(lambda, log.p=TRUE)+dnorm(x*sqrt(1+eta^2)/(sigma*(sqrt(1+eta^2)-eta))-lambda,log=TRUE)*ifelse(x>=0,1,0)+dnorm(-x*sqrt(1+eta^2)/(sigma*(sqrt(1+eta^2)+eta))-lambda,log=TRUE)*ifelse(x<0,1,0)
     if (!log) 
