@@ -9,9 +9,9 @@ if(is.null(x))
     stop("lambda must be specified")
   if(is.null(q))
     stop("q must be specified")
-  if(sigma<=0)
+  if(any(sigma<=0))
     stop("sigma must be positive")
-  if(q<=0)
+  if(any(q<=0))
     stop("q must be positive")
   if(any(x<=0))
     stop("x's must be positive")
