@@ -7,7 +7,7 @@ if(is.null(x))
     stop("sigma must be specified")
   if(is.null(lambda))
     stop("lambda must be specified")
-  if(sigma<=0)
+  if(any(sigma<=0))
     stop("sigma must be positive")
   if(any(x<=0))
     stop("x's must be positive")
