@@ -7,7 +7,7 @@ function(x, sigma=1, lambda=0, eta=0, lower.tail = TRUE, log = FALSE)
         stop("sigma must be specified")
     if (is.null(lambda)) 
         stop("lambda must be specified")
-    if (sigma <= 0) 
+    if (any(sigma <= 0)) 
         stop("sigma must be positive")
     epsilon = eta/(sqrt(1+eta^2))
     lf1 = 0.5*(1+epsilon)*(exp(-pnorm(lambda, log.p=TRUE))-exp(pnorm(-x/(sigma*(1+epsilon))-lambda, log.p=TRUE)-pnorm(lambda, log.p=TRUE)))
