@@ -9,9 +9,9 @@ if(is.null(x))
     stop("lambda must be specified")
   if(is.null(nu))
     stop("nu must be specified")
-  if(sigma<=0)
+  if(any(sigma<=0))
     stop("sigma must be positive")
-  if(nu<=0)
+  if(any(nu<=0))
     stop("nu must be positive")
   if(any(x<=0))
     stop("x's must be positive")
