@@ -7,7 +7,7 @@ putpn<-function (x, sigma=1, lambda=0, type=1, lower.tail = TRUE, log = FALSE)
         stop("sigma must be specified")
     if (is.null(lambda)) 
         stop("lambda must be specified")
-    if (sigma <= 0) 
+    if (any(sigma <= 0)) 
         stop("sigma must be positive")
     if (any(x <= 0)) 
         stop("x's must be positive")
