@@ -7,7 +7,7 @@ qutpn<-function(p, sigma=1, lambda=0, type=1)
         stop("sigma must be specified")
     if (is.null(lambda)) 
         stop("lambda must be specified")
-    if (sigma <= 0) 
+    if (any(sigma <= 0)) 
         stop("sigma must be positive")
     if (any(p <= 0 | p>=1)) 
         stop("p's must be between 0 and 1")
