@@ -9,7 +9,7 @@ function(n, sigma=1, lambda=0, eta=0)
         stop("lambda must be specified")
     if (is.null(eta)) 
         stop("eta must be specified")
-    if (sigma <= 0) 
+    if (any(sigma <= 0)) 
         stop("sigma must be positive")
     if (n <= 0 | round(n) != n) 
         stop("sample size must be a positive integer")
