@@ -5,6 +5,6 @@ n<-round(n)
 if(n<=0) stop("n must be positive")
 if(!any(dist == c("norm", "logis", "cauchy", "laplace"))) 
             stop("distribution is not recognized")
-if(sigma<=0) stop("sigma must be positive")
+if(any(sigma<=0)) stop("sigma must be positive")
 qfts(runif(n), sigma=sigma, lambda=lambda, dist=dist)
 }
