@@ -9,7 +9,7 @@ if(is.null(n))
     stop("lambda must be specified")
   if(is.null(q))
     stop("q must be specified")
-  if(sigma<=0)
+  if(any(sigma<=0))
     stop("sigma must be positive")
   if(q<=0)
     stop("q must be positive")
