@@ -11,9 +11,9 @@ if(is.null(n))
     stop("nu must be specified")
   if(n<=0 | round(n)!=n)
     stop("sample size must be a positive integer")      
-  if(sigma<=0)
+  if(any(sigma<=0))
     stop("sigma must be positive")
-  if(nu<=0)
+  if(any(nu<=0))
     stop("sigma must be positive")
 v=runif(n)
 u=runif(n)
